@@ -1,7 +1,4 @@
-from blockapi.services import (
-    BlockchainAPI,
-    on_failure_return_none
-)
+from blockapi.services import BlockchainAPI
 
 
 class EthplorerAPI(BlockchainAPI):
@@ -36,7 +33,6 @@ class EthplorerAPI(BlockchainAPI):
         if self.api_key != self.default_api_key:
             self.rate_limit = 0.1
 
-    @on_failure_return_none()
     def get_balance(self):
         balances = []
         response = self.info
@@ -52,13 +48,13 @@ class EthplorerAPI(BlockchainAPI):
             decimals = int(info['decimals']) if info.get('decimals') else 18
 
             balances.append({
-                'symbol': info['symbol'],
+                'symbol': info.get('symbol', 'unknown'),
                 'address': info['address'],
                 'amount': token['balance'] * pow(10, -decimals),
-                'name': info['name']
+                'name': info.get('name', 'Unknown')
             })
 
-        if balances == []:
+        if not balances:
             return None
 
         return balances
