@@ -31,7 +31,7 @@ class Service(ABC):
         path_url = self.supported_requests.get(request_method)
         if path_url:
             return self.base_url + path_url.format(**params)
-        return None
+        return self.base_url
 
     def request(self, request_method, with_rate_limit=False,
                 with_cloudflare=False, body=None, headers=None, **params):
@@ -58,7 +58,7 @@ class Service(ABC):
         if body:
             response = reqobj.post(request_url, data=body, headers=headers)
         else:
-            response = reqobj.get(request_url)
+            response = reqobj.get(request_url, headers=headers)
 
         self.last_response = response
         self.last_response_time = datetime.now()
@@ -216,3 +216,25 @@ class BlockchainAPI(Service, BlockchainInterface, ABC):
                 self.base_url = self.testnet_url
             else:
                 raise ValueError("API doesn't support testnet.")
+
+    def _load(self, data):
+        from decimal import Decimal
+
+        if isinstance(data, dict):
+            for key in data:
+                data[key] = self._load(data[key])
+            return data
+        elif isinstance(data, list):
+            for i, elem in enumerate(data):
+                data[i] = self._load(elem)
+            return data
+        elif isinstance(data, str):
+            new = None
+            try:
+                new = Decimal(data)
+            except ValueError:
+                new = data
+            finally:
+                return new
+        else:
+            return data
